package com.saye.hospitalgd.service.quartz;

import java.util.HashMap;
import java.util.List;

import com.saye.hospitalgd.model.BaseQuartzConfigEntity;

public interface BaseQuartzConfigService {

	public List<BaseQuartzConfigEntity> findAll(HashMap<Object, Object> map) throws Exception;

	public BaseQuartzConfigEntity get(String id) throws Exception;

	public void updateQuartzConfig(BaseQuartzConfigEntity quartzConfigEntity)throws Exception;

	public List<HashMap<Object, Object>> findMaxId() throws Exception;

	public void addQuartz(HashMap<Object, Object> addMap) throws Exception;

	public List<HashMap<Object, Object>> findOrderProjectList() throws Exception;

	public void deleteQuartzConfigById(String id) throws Exception;

	public void updateQuartzConfigById(HashMap<Object, Object> updateMap) throws Exception;


}
